pub fn render_summary(model: &ExplanationModel) -> StringExpand description
Five sections within twenty logical lines, including mandatory diagnostics.
pub fn render_summary(model: &ExplanationModel) -> StringFive sections within twenty logical lines, including mandatory diagnostics.