pub fn replay(
events: impl IntoIterator<Item = ThreadEvent>,
) -> MatrixResult<BTreeMap<String, MatrixState>>Expand description
Latest complete durable checkpoint for each matrix, in stable ID order.
pub fn replay(
events: impl IntoIterator<Item = ThreadEvent>,
) -> MatrixResult<BTreeMap<String, MatrixState>>Latest complete durable checkpoint for each matrix, in stable ID order.