create_audit_pack

Function create_audit_pack 

pub fn create_audit_pack(
    workspace: &Path,
    session_id: &str,
) -> Result<SessionAuditPack, SessionStoreError>
Build a digest manifest of session_id’s store.

Errors

Returns SessionStoreError when the session directory or its manifest cannot be read, or when any file cannot be digested.