pub fn open(
workspace: &Path,
session_id: &str,
max_events: usize,
) -> Result<SessionEventLog, SessionStoreError>Expand description
Open (creating if necessary) the event log for a session.
This is the canonical entry point for recording a session’s events. Multiple
handles opened for the same session share an Arc-backed file and state,
allowing concurrent append calls from the runloop’s event sink to use one
coordinated turn index.