Retention and garbage-collection for the unified session store.
Structs
- Retention
Policy - Retention policy applied to the set of per-session stores.
Functions
- apply_
retention - Apply the retention policy, removing the oldest / stale sessions.
- apply_
retention_ preserving - Apply retention while preserving one session directory, even when its
existing manifest still says
completed(for example, a resumed session). - gc_
legacy - Remove the legacy
history/andlogs/directories after they have been imported into the unified store bycrate::migrate_legacy.